@@ -3,6 +3,7 @@ import os
 import queue
 import sys
 import textwrap
+from typing import Union
 
 import py
 
@@ -59,9 +60,9 @@ def test_excinfo_getstatement():
     except ValueError:
         excinfo = _pytest._code.ExceptionInfo.from_current()
     linenumbers = [
-        _pytest._code.getrawcode(f).co_firstlineno - 1 + 4,
-        _pytest._code.getrawcode(f).co_firstlineno - 1 + 1,
-        _pytest._code.getrawcode(g).co_firstlineno - 1 + 1,
+        f.__code__.co_firstlineno - 1 + 4,
+        f.__code__.co_firstlineno - 1 + 1,
+        g.__code__.co_firstlineno - 1 + 1,
     ]
     values = list(excinfo.traceback)
     foundlinenumbers = [x.lineno for x in values]
@@ -224,23 +225,25 @@ class TestTraceback_f_g_h:
         repr = excinfo.getrepr()
         assert "RuntimeError: hello" in str(repr.reprcrash)
 
-    def test_traceback_no_recursion_index(self):
-        def do_stuff():
+    def test_traceback_no_recursion_index(self) -> None:
+        def do_stuff() -> None:
             raise RuntimeError
 
-        def reraise_me():
+        def reraise_me() -> None:
             import sys
 
             exc, val, tb = sys.exc_info()
+            assert val is not None
             raise val.with_traceback(tb)
 
-        def f(n):
+        def f(n: int) -> None:
             try:
                 do_stuff()
             except:  # noqa
                 reraise_me()
 
         excinfo = pytest.raises(RuntimeError, f, 8)
+        assert excinfo is not None
         traceback = excinfo.traceback
         recindex = traceback.recursionindex()
         assert recindex is None
@@ -316,8 +319,19 @@ def test_excinfo_exconly():
 
 def test_excinfo_repr_str():
     excinfo = pytest.raises(ValueError, h)
-    assert repr(excinfo) == "<ExceptionInfo ValueError tblen=4>"
-    assert str(excinfo) == "<ExceptionInfo ValueError tblen=4>"
+    assert repr(excinfo) == "<ExceptionInfo ValueError() tblen=4>"
+    assert str(excinfo) == "<ExceptionInfo ValueError() tblen=4>"
+
+    class CustomException(Exception):
+        def __repr__(self):
+            return "custom_repr"
+
+    def raises():
+        raise CustomException()
+
+    excinfo = pytest.raises(CustomException, raises)
+    assert repr(excinfo) == "<ExceptionInfo custom_repr tblen=2>"
+    assert str(excinfo) == "<ExceptionInfo custom_repr tblen=2>"
 
 
 def test_excinfo_for_later():
@@ -399,7 +413,7 @@ def test_match_raises_error(testdir):
     result = testdir.runpytest()
     assert result.ret != 0
     result.stdout.fnmatch_lines(["*AssertionError*Pattern*[123]*not found*"])
-    assert "__tracebackhide__ = True" not in result.stdout.str()
+    result.stdout.no_fnmatch_line("*__tracebackhide__ = True*")
 
     result = testdir.runpytest("--fulltrace")
     assert result.ret != 0
@@ -491,65 +505,18 @@ raise ValueError()
         assert repr.reprtraceback.reprentries[1].lines[0] == ">   ???"
         assert repr.chain[0][0].reprentries[1].lines[0] == ">   ???"
 
-    def test_repr_source_failing_fullsource(self):
+    def test_repr_source_failing_fullsource(self, monkeypatch) -> None:
         pr = FormattedExcinfo()
 
-        class FakeCode:
-            class raw:
-                co_filename = "?"
+        try:
+            1 / 0
+        except ZeroDivisionError:
+            excinfo = ExceptionInfo.from_current()
 
-            path = "?"
-            firstlineno = 5
+        with monkeypatch.context() as m:
+            m.setattr(_pytest._code.Code, "fullsource", property(lambda self: None))
+            repr = pr.repr_excinfo(excinfo)
 
-            def fullsource(self):
-                return None
-
-            fullsource = property(fullsource)
-
-        class FakeFrame:
-            code = FakeCode()
-            f_locals = {}
-            f_globals = {}
-
-        class FakeTracebackEntry(_pytest._code.Traceback.Entry):
-            def __init__(self, tb, excinfo=None):
-                self.lineno = 5 + 3
-
-            @property
-            def frame(self):
-                return FakeFrame()
-
-        class Traceback(_pytest._code.Traceback):
-            Entry = FakeTracebackEntry
-
-        class FakeExcinfo(_pytest._code.ExceptionInfo):
-            typename = "Foo"
-            value = Exception()
-
-            def __init__(self):
-                pass
-
-            def exconly(self, tryshort):
-                return "EXC"
-
-            def errisinstance(self, cls):
-                return False
-
-        excinfo = FakeExcinfo()
-
-        class FakeRawTB:
-            tb_next = None
-
-        tb = FakeRawTB()
-        excinfo.traceback = Traceback(tb)
-
-        fail = IOError()
-        repr = pr.repr_excinfo(excinfo)
-        assert repr.reprtraceback.reprentries[0].lines[0] == ">   ???"
-        assert repr.chain[0][0].reprentries[0].lines[0] == ">   ???"
-
-        fail = py.error.ENOENT  # noqa
-        repr = pr.repr_excinfo(excinfo)
         assert repr.reprtraceback.reprentries[0].lines[0] == ">   ???"
         assert repr.chain[0][0].reprentries[0].lines[0] == ">   ???"
 
@@ -573,7 +540,7 @@ raise ValueError()
         reprlocals = p.repr_locals(loc)
         assert reprlocals.lines
         assert reprlocals.lines[0] == "__builtins__ = <builtins>"
-        assert '[NotImplementedError("") raised in repr()]' in reprlocals.lines[1]
+        assert "[NotImplementedError() raised in repr()]" in reprlocals.lines[1]
 
     def test_repr_local_with_exception_in_class_property(self):
         class ExceptionWithBrokenClass(Exception):
@@ -591,7 +558,7 @@ raise ValueError()
         reprlocals = p.repr_locals(loc)
         assert reprlocals.lines
         assert reprlocals.lines[0] == "__builtins__ = <builtins>"
-        assert '[ExceptionWithBrokenClass("") raised in repr()]' in reprlocals.lines[1]
+        assert "[ExceptionWithBrokenClass() raised in repr()]" in reprlocals.lines[1]
 
     def test_repr_local_truncated(self):
         loc = {"l": [i for i in range(10)]}
@@ -632,7 +599,6 @@ raise ValueError()
         assert lines[3] == "E       world"
         assert not lines[4:]
 
-        loc = repr_entry.reprlocals is not None
         loc = repr_entry.reprfileloc
         assert loc.path == mod.__file__
         assert loc.lineno == 3
@@ -891,7 +857,7 @@ raise ValueError()
         from _pytest._code.code import TerminalRepr
 
         class MyRepr(TerminalRepr):
-            def toterminal(self, tw):
+            def toterminal(self, tw) -> None:
                 tw.line("я")
 
         x = str(MyRepr())
@@ -1218,13 +1184,15 @@ raise ValueError()
     @pytest.mark.parametrize(
         "reason, description",
         [
-            (
+            pytest.param(
                 "cause",
                 "The above exception was the direct cause of the following exception:",
+                id="cause",
             ),
-            (
+            pytest.param(
                 "context",
                 "During handling of the above exception, another exception occurred:",
+                id="context",
             ),
         ],
     )
@@ -1320,9 +1288,10 @@ raise ValueError()
 @pytest.mark.parametrize("style", ["short", "long"])
 @pytest.mark.parametrize("encoding", [None, "utf8", "utf16"])
 def test_repr_traceback_with_unicode(style, encoding):
-    msg = "☹"
-    if encoding is not None:
-        msg = msg.encode(encoding)
+    if encoding is None:
+        msg = "☹"  # type: Union[str, bytes]
+    else:
+        msg = "☹".encode(encoding)
     try:
         raise RuntimeError(msg)
     except RuntimeError:
@@ -1343,7 +1312,8 @@ def test_cwd_deleted(testdir):
     )
     result = testdir.runpytest()
     result.stdout.fnmatch_lines(["* 1 failed in *"])
-    assert "INTERNALERROR" not in result.stdout.str() + result.stderr.str()
+    result.stdout.no_fnmatch_line("*INTERNALERROR*")
+    result.stderr.no_fnmatch_line("*INTERNALERROR*")
 
 
 @pytest.mark.usefixtures("limited_recursion_depth")
