@@ -1,7 +1,6 @@
 import os
 import platform
 from datetime import datetime
-from pathlib import Path
 from xml.dom import minidom
 
 import py
@@ -9,6 +8,7 @@ import xmlschema
 
 import pytest
 from _pytest.junitxml import LogXML
+from _pytest.pathlib import Path
 from _pytest.reports import BaseReport
 
 
@@ -477,22 +477,25 @@ class TestPython:
         assert "ValueError" in fnode.toxml()
         systemout = fnode.next_sibling
         assert systemout.tag == "system-out"
-        assert "hello-stdout" in systemout.toxml()
-        assert "info msg" not in systemout.toxml()
+        systemout_xml = systemout.toxml()
+        assert "hello-stdout" in systemout_xml
+        assert "info msg" not in systemout_xml
         systemerr = systemout.next_sibling
         assert systemerr.tag == "system-err"
-        assert "hello-stderr" in systemerr.toxml()
-        assert "info msg" not in systemerr.toxml()
+        systemerr_xml = systemerr.toxml()
+        assert "hello-stderr" in systemerr_xml
+        assert "info msg" not in systemerr_xml
 
         if junit_logging == "system-out":
-            assert "warning msg" in systemout.toxml()
-            assert "warning msg" not in systemerr.toxml()
+            assert "warning msg" in systemout_xml
+            assert "warning msg" not in systemerr_xml
         elif junit_logging == "system-err":
-            assert "warning msg" not in systemout.toxml()
-            assert "warning msg" in systemerr.toxml()
-        elif junit_logging == "no":
-            assert "warning msg" not in systemout.toxml()
-            assert "warning msg" not in systemerr.toxml()
+            assert "warning msg" not in systemout_xml
+            assert "warning msg" in systemerr_xml
+        else:
+            assert junit_logging == "no"
+            assert "warning msg" not in systemout_xml
+            assert "warning msg" not in systemerr_xml
 
     @parametrize_families
     def test_failure_verbose_message(self, testdir, run_and_parse, xunit_family):
@@ -1216,7 +1219,7 @@ def test_runs_twice(testdir, run_and_parse):
     )
 
     result, dom = run_and_parse(f, f)
-    assert "INTERNALERROR" not in result.stdout.str()
+    result.stdout.no_fnmatch_line("*INTERNALERROR*")
     first, second = [x["classname"] for x in dom.find_by_tag("testcase")]
     assert first == second
 
@@ -1231,7 +1234,7 @@ def test_runs_twice_xdist(testdir, run_and_parse):
     )
 
     result, dom = run_and_parse(f, "--dist", "each", "--tx", "2*popen")
-    assert "INTERNALERROR" not in result.stdout.str()
+    result.stdout.no_fnmatch_line("*INTERNALERROR*")
     first, second = [x["classname"] for x in dom.find_by_tag("testcase")]
     assert first == second
 
@@ -1271,7 +1274,7 @@ def test_fancy_items_regression(testdir, run_and_parse):
 
     result, dom = run_and_parse()
 
-    assert "INTERNALERROR" not in result.stdout.str()
+    result.stdout.no_fnmatch_line("*INTERNALERROR*")
 
     items = sorted("%(classname)s %(name)s" % x for x in dom.find_by_tag("testcase"))
     import pprint
