@@ -193,7 +193,7 @@ class TestPDB:
         )
         child = testdir.spawn_pytest("-rs --pdb %s" % p1)
         child.expect("Skipping also with pdb active")
-        child.expect("1 skipped in")
+        child.expect_exact("= \x1b[33m\x1b[1m1 skipped\x1b[0m\x1b[33m in")
         child.sendeof()
         self.flush(child)
 
@@ -221,7 +221,7 @@ class TestPDB:
         child.sendeof()
         rest = child.read().decode("utf8")
         assert "Exit: Quitting debugger" in rest
-        assert "= 1 failed in" in rest
+        assert "= \x1b[31m\x1b[1m1 failed\x1b[0m\x1b[31m in" in rest
         assert "def test_1" not in rest
         assert "get rekt" not in rest
         self.flush(child)
@@ -466,7 +466,6 @@ class TestPDB:
     def test_pdb_interaction_doctest(self, testdir, monkeypatch):
         p1 = testdir.makepyfile(
             """
-            import pytest
             def function_1():
                 '''
                 >>> i = 0
@@ -485,9 +484,32 @@ class TestPDB:
 
         child.sendeof()
         rest = child.read().decode("utf8")
+        assert "! _pytest.outcomes.Exit: Quitting debugger !" in rest
+        assert "BdbQuit" not in rest
         assert "1 failed" in rest
         self.flush(child)
 
+    def test_doctest_set_trace_quit(self, testdir, monkeypatch):
+        p1 = testdir.makepyfile(
+            """
+            def function_1():
+                '''
+                >>> __import__('pdb').set_trace()
+                '''
+        """
+        )
+        # NOTE: does not use pytest.set_trace, but Python's patched pdb,
+        #       therefore "-s" is required.
+        child = testdir.spawn_pytest("--doctest-modules --pdb -s %s" % p1)
+        child.expect("Pdb")
+        child.sendline("q")
+        rest = child.read().decode("utf8")
+
+        assert "! _pytest.outcomes.Exit: Quitting debugger !" in rest
+        assert "= \x1b[33mno tests ran\x1b[0m\x1b[33m in" in rest
+        assert "BdbQuit" not in rest
+        assert "UNEXPECTED EXCEPTION" not in rest
+
     def test_pdb_interaction_capturing_twice(self, testdir):
         p1 = testdir.makepyfile(
             """
@@ -581,7 +603,7 @@ class TestPDB:
         # No extra newline.
         assert child.before.endswith(b"c\r\nprint_from_foo\r\n")
 
-        # set_debug should not raise outcomes.Exit, if used recrursively.
+        # set_debug should not raise outcomes. Exit, if used recursively.
         child.sendline("debug 42")
         child.sendline("q")
         child.expect("LEAVING RECURSIVE DEBUGGER")
@@ -703,7 +725,7 @@ class TestPDB:
             assert "> PDB continue (IO-capturing resumed) >" in rest
         else:
             assert "> PDB continue >" in rest
-        assert "1 passed in" in rest
+        assert "= \x1b[32m\x1b[1m1 passed\x1b[0m\x1b[32m in" in rest
 
     def test_pdb_used_outside_test(self, testdir):
         p1 = testdir.makepyfile(
@@ -1019,7 +1041,52 @@ class TestTraceOption:
         child.sendline("q")
         child.expect_exact("Exit: Quitting debugger")
         rest = child.read().decode("utf8")
-        assert "2 passed in" in rest
+        assert "= \x1b[32m\x1b[1m2 passed\x1b[0m\x1b[32m in" in rest
+        assert "reading from stdin while output" not in rest
+        # Only printed once - not on stderr.
+        assert "Exit: Quitting debugger" not in child.before.decode("utf8")
+        TestPDB.flush(child)
+
+    def test_trace_with_parametrize_handles_shared_fixtureinfo(self, testdir):
+        p1 = testdir.makepyfile(
+            """
+            import pytest
+            @pytest.mark.parametrize('myparam', [1,2])
+            def test_1(myparam, request):
+                assert myparam in (1, 2)
+                assert request.function.__name__ == "test_1"
+            @pytest.mark.parametrize('func', [1,2])
+            def test_func(func, request):
+                assert func in (1, 2)
+                assert request.function.__name__ == "test_func"
+            @pytest.mark.parametrize('myparam', [1,2])
+            def test_func_kw(myparam, request, func="func_kw"):
+                assert myparam in (1, 2)
+                assert func == "func_kw"
+                assert request.function.__name__ == "test_func_kw"
+            """
+        )
+        child = testdir.spawn_pytest("--trace " + str(p1))
+        for func, argname in [
+            ("test_1", "myparam"),
+            ("test_func", "func"),
+            ("test_func_kw", "myparam"),
+        ]:
+            child.expect_exact("> PDB runcall (IO-capturing turned off) >")
+            child.expect_exact(func)
+            child.expect_exact("Pdb")
+            child.sendline("args")
+            child.expect_exact("{} = 1\r\n".format(argname))
+            child.expect_exact("Pdb")
+            child.sendline("c")
+            child.expect_exact("Pdb")
+            child.sendline("args")
+            child.expect_exact("{} = 2\r\n".format(argname))
+            child.expect_exact("Pdb")
+            child.sendline("c")
+            child.expect_exact("> PDB continue (IO-capturing resumed) >")
+        rest = child.read().decode("utf8")
+        assert "= \x1b[32m\x1b[1m6 passed\x1b[0m\x1b[32m in" in rest
         assert "reading from stdin while output" not in rest
         # Only printed once - not on stderr.
         assert "Exit: Quitting debugger" not in child.before.decode("utf8")
@@ -1130,7 +1197,7 @@ def test_pdb_suspends_fixture_capturing(testdir, fixture):
 
     TestPDB.flush(child)
     assert child.exitstatus == 0
-    assert "= 1 passed in " in rest
+    assert "= \x1b[32m\x1b[1m1 passed\x1b[0m\x1b[32m in" in rest
     assert "> PDB continue (IO-capturing resumed for fixture %s) >" % (fixture) in rest
 
 
@@ -1150,7 +1217,6 @@ def test_pdbcls_via_local_module(testdir):
 
                 def runcall(self, *args, **kwds):
                     print("runcall_called", args, kwds)
-                    assert "func" in kwds
         """,
     )
     result = testdir.runpytest(
