@@ -133,17 +133,17 @@ class TestReportSerialization:
         """
         reprec = testdir.inline_runsource(
             """
-            import py
+            import pytest
             def test_pass(): pass
             def test_fail(): 0/0
-            @py.test.mark.skipif("True")
+            @pytest.mark.skipif("True")
             def test_skip(): pass
             def test_skip_imperative():
-                py.test.skip("hello")
-            @py.test.mark.xfail("True")
+                pytest.skip("hello")
+            @pytest.mark.xfail("True")
             def test_xfail(): 0/0
             def test_xfail_imperative():
-                py.test.xfail("hello")
+                pytest.xfail("hello")
         """
         )
         reports = reprec.getreports("pytest_runtest_logreport")
@@ -330,7 +330,7 @@ class TestHooks:
             data = pytestconfig.hook.pytest_report_to_serializable(
                 config=pytestconfig, report=rep
             )
-            assert data["_report_type"] == "TestReport"
+            assert data["$report_type"] == "TestReport"
             new_rep = pytestconfig.hook.pytest_report_from_serializable(
                 config=pytestconfig, data=data
             )
@@ -352,7 +352,7 @@ class TestHooks:
             data = pytestconfig.hook.pytest_report_to_serializable(
                 config=pytestconfig, report=rep
             )
-            assert data["_report_type"] == "CollectReport"
+            assert data["$report_type"] == "CollectReport"
             new_rep = pytestconfig.hook.pytest_report_from_serializable(
                 config=pytestconfig, data=data
             )
@@ -376,7 +376,7 @@ class TestHooks:
         data = pytestconfig.hook.pytest_report_to_serializable(
             config=pytestconfig, report=rep
         )
-        data["_report_type"] = "Unknown"
+        data["$report_type"] = "Unknown"
         with pytest.raises(AssertionError):
             _ = pytestconfig.hook.pytest_report_from_serializable(
                 config=pytestconfig, data=data
