@@ -4,7 +4,7 @@ import pytest
 @pytest.fixture
 def stepwise_testdir(testdir):
     # Rather than having to modify our testfile between tests, we introduce
-    # a flag for wether or not the second test should fail.
+    # a flag for whether or not the second test should fail.
     testdir.makeconftest(
         """
 def pytest_addoption(parser):
@@ -164,7 +164,7 @@ def test_stop_on_collection_errors(broken_testdir, broken_first):
     if broken_first:
         files.reverse()
     result = broken_testdir.runpytest("-v", "--strict-markers", "--stepwise", *files)
-    result.stdout.fnmatch_lines("*errors during collection*")
+    result.stdout.fnmatch_lines("*error during collection*")
 
 
 def test_xfail_handling(testdir):
